package com.halo.halojuhesdk.core.base.net;

import android.content.Context;
import android.net.ConnectivityManager;
import android.net.NetworkInfo;
import android.telephony.TelephonyManager;

/**
 * 网络管理器(用于判断当前网络连接类型，接入点，代理服务器信息)
 *
 * @author david
 */
public class NetworkManager {

    public static final int NET_WIFI = 0x01;
    public static final int NET_4G = 0x02;
    public static final int NET_3G = 0x03;
    public static final int NET_2G = 0x04;
    public static final int NET_UNKNOWN = 0x05;
    public static final int NET_NONE = 0x06;

    public static final int HJ_ACCEPT_NET_LEVEL = NET_NONE;
    public static int HJ_ACCEPT_DOWNLOAD_NET_LEVEL = NET_NONE;

    /**
     * 判断当前是否有网
     * <p>
     * 1 Wifi
     * <p>
     * 2 4G
     * <p>
     * 3 3G
     * <p>
     * 4 2G
     * <p>
     * 6 无网
     *
     * @param cx
     * @return 判断值
     */
    public static int getNetworkType(Context cx) {

        ConnectivityManager cwjManager = (ConnectivityManager) cx
                .getSystemService(Context.CONNECTIVITY_SERVICE);
        NetworkInfo info = cwjManager.getActiveNetworkInfo();
        if (info == null)
            return NET_NONE;// 无网
        int netType = info.getType();
        if (netType == ConnectivityManager.TYPE_WIFI)
            return NET_WIFI;// wifi
        else if (netType == ConnectivityManager.TYPE_MOBILE) {
            return getMobileNetClass(info.getSubtype());// 各种手机网络
        }
        return 0;
    }


    /**
     * 当前网络是否可用
     *
     * @param cxt Context
     * @return activeNetInfo.isConnected();
     */
    public static boolean isNetworkConnected(Context cxt) {
        ConnectivityManager connectivityManager = (ConnectivityManager) cxt
                .getApplicationContext().getSystemService(
                        Context.CONNECTIVITY_SERVICE);

        NetworkInfo activeNetInfo = connectivityManager.getActiveNetworkInfo();
        if (activeNetInfo != null) {
            return activeNetInfo.isConnectedOrConnecting();
        }
        return false;
    }

    /**
     * 区分手机制式
     *
     * @param networkType
     * @return
     */
    private static int getMobileNetClass(int networkType) {

        switch (networkType) {
            case TelephonyManager.NETWORK_TYPE_GPRS:
            case TelephonyManager.NETWORK_TYPE_EDGE:
            case TelephonyManager.NETWORK_TYPE_CDMA:
            case TelephonyManager.NETWORK_TYPE_1xRTT:
            case TelephonyManager.NETWORK_TYPE_IDEN:
                return NET_2G;
            case TelephonyManager.NETWORK_TYPE_UMTS:
            case TelephonyManager.NETWORK_TYPE_EVDO_0:
            case TelephonyManager.NETWORK_TYPE_EVDO_A:
            case TelephonyManager.NETWORK_TYPE_HSDPA:
            case TelephonyManager.NETWORK_TYPE_HSUPA:
            case TelephonyManager.NETWORK_TYPE_HSPA:
            case TelephonyManager.NETWORK_TYPE_EVDO_B:
            case TelephonyManager.NETWORK_TYPE_EHRPD:
            case TelephonyManager.NETWORK_TYPE_HSPAP:
                return NET_3G;
            case TelephonyManager.NETWORK_TYPE_LTE:
                return NET_4G;
            default:
                return NET_UNKNOWN;
        }
    }

}
