package com.halo.halojuhesdk.core.channel.applovin;

import android.app.Activity;
import android.util.Log;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.applovin.mediation.MaxAd;
import com.applovin.mediation.MaxAdRevenueListener;
import com.applovin.mediation.MaxError;
import com.applovin.mediation.nativeAds.MaxNativeAdListener;
import com.applovin.mediation.nativeAds.MaxNativeAdLoader;
import com.applovin.mediation.nativeAds.MaxNativeAdView;
import com.halo.halojuhesdk.core.base.utils.CompareEcpmUtils;
import com.halo.halojuhesdk.core.channel.INativeAd;
import com.halo.halojuhesdk.core.channel.INativeProxyListener;
import com.halo.halojuhesdk.core.request.EcpmCompareBean;
import com.halo.halojuhesdk.core.request.InitDataProcessor;
import com.halo.halojuhesdk.core.request.SlotBean;
import com.halo.halojuhesdk.sdk.HlAdClient;

public class AppLovinNative extends MaxNativeAdListener implements INativeAd, MaxAdRevenueListener {
    private MaxNativeAdLoader nativeAdLoader;
    private SlotBean mLovinBean;
    private INativeProxyListener mNativeListener;
    private boolean isShow = true;
    private boolean isClick = false;
    private MaxNativeAdView mNativeView;

    public AppLovinNative(Activity activity, SlotBean bean, final INativeProxyListener listener) {
        this.mNativeListener = listener;
        this.mLovinBean = bean;
        InitDataProcessor.initAppLovin(activity, bean.extendStr);
        mLovinBean.setStartTime(System.currentTimeMillis());
        nativeAdLoader = new MaxNativeAdLoader(bean.adSlotId, activity);
        nativeAdLoader.setNativeAdListener(this);
        nativeAdLoader.setRevenueListener(this);
    }


    @Override
    public void loadAd() {
        if (nativeAdLoader != null) {
            nativeAdLoader.loadAd();
        }
    }

    @Override
    public void onNativeAdLoaded(@Nullable final MaxNativeAdView nativeAdView, final MaxAd ad) {
        mLovinBean.setEndTime(System.currentTimeMillis());
        if (ad != null && nativeAdView != null) {
            double ecpm = ad.getRevenue()*1000;
            mLovinBean.setEp(ecpm);
            mNativeView = nativeAdView;
            EcpmCompareBean bean = CompareEcpmUtils.compareEcpm(mLovinBean, ecpm);
            mLovinBean.setOp(bean.getEcpm());
            if (bean.getResult()) {
                mNativeListener.onADLoadView(nativeAdView, InitDataProcessor.SDK_MAX, mLovinBean, bean.getEcpm(), ad.getNetworkName());
            } else {
                if (mNativeListener != null) {
                    mNativeListener.onADError("max:竞价失败" , 102, InitDataProcessor.SDK_MAX, mLovinBean);
                }
            }
        } else {
            if (mNativeListener != null) {
                mNativeListener.onADError("数据空值", 102, InitDataProcessor.SDK_MAX, mLovinBean);
            }
        }
    }

    @Override
    public void onNativeAdLoadFailed(String adUnitId, MaxError error) {
        mLovinBean.setEndTime(System.currentTimeMillis());
        if (mNativeListener != null) {
            mNativeListener.onADError(error.getMessage(), error.getCode(), InitDataProcessor.SDK_MAX, mLovinBean);
        }
    }

    @Override
    public void onNativeAdClicked(final MaxAd ad) {
        if (!isClick) {
            isClick = true;
            mNativeListener.onADClick(mNativeView, mLovinBean, ad.getNetworkName());
        }
    }

    @Override
    public void onAdRevenuePaid(@NonNull MaxAd maxAd) {
        Log.e("11111","===onAdRevenuePaid===");
        if (isShow) {
            isShow = false;
            mNativeListener.onADShow(mNativeView, InitDataProcessor.SDK_MAX, mLovinBean, maxAd.getNetworkName());
        }
    }

    @Override
    public void onNativeAdExpired(final MaxAd nativeAd) {

    }

    @Override
    public void release() {

    }

}
